#!/bin/bash

# set -x # Handle all errors here - remove -x before shipping

# *****************************************************************
#
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2016, 2019. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# *****************************************************************

function usage {
    # usage
    echo "usage:`basename $0` "
    echo " "
    echo "      Before calling powerai-license-accept.sh, set the"
    echo "      IBM_POWERAI_LICENSE_ACCEPT environment variable"
    echo "      to one of the following values:"
    echo " "
    echo "        yes = Automatic license acceptance."
    echo "        no  = Manual license acceptance.   "
    echo " "
    exit 1
}

#-------------------------------------------------------------------------
if [ $# -gt 1 ]; then
    usage
fi

if [[ $IBM_POWERAI_LICENSE_ACCEPT = 'yes' ]]; then
    SILENT_MODE=yes
elif [[ $IBM_POWERAI_LICENSE_ACCEPT = 'no' ]]; then
    SILENT_MODE=no
else
    SILENT_MODE=no
fi

E_LAPDECLINE=1
E_FILENOTFOUND=3
E_NOTUNIQUE=4
LAP=lapc

while [ $# -gt 0 ]
do
    case $1 in
        -h|-help|-*|*)
            usage
            ;;
    esac
done

function click_accept {
#******************************************************************************
#* Runs license accept process..
#*
#* Return values of LAP tool:
#* 1 : no LAP status available
#* 3 : declined
#* 5 : bypassed
#* 9 : accepted
#* 11: exception during retrieval of LA files
#* 13: exception during retrieval of LI files
#* 15: exception during recording of status and text license files
#* 17: missing arguments exception
#* 18: invalid arguments exception
#* 19: path to license files is invalid
#* 20: path to read status file is invalid
#* 21: path to write status file is invalid
#******************************************************************************
  SILENT_MODE=$1
  if [ $SILENT_MODE = yes ]
  then
    SILENT="-t 5"
  fi
  # License Acceptance Process..
  LAP_PATH=${PREFIX}"/lap_se" # PREFIX is from conda install
  LICENSE_FILES_PATH=${PREFIX}"/lap_se/"
  USER_POWERAI_PATH=${HOME}"/${POWERAI_LICENSE_DIR}"
  STATUS_PATH=${USER_POWERAI_PATH}"/powerai-license/${POWERAI_LICENSE_REL}"
  STATUS_FILE=${STATUS_PATH}"/license/status.dat"

  # Don't re-run lapc tool if license was previously accepted.
  # Re-running the lapc tool re-writes the files changing the time-stamps.
  if [ -s "$STATUS_FILE" ]; then
      return 9;
  fi

  LAP_CMD="${LAP_PATH}/${LAP}\
    -l ${LICENSE_FILES_PATH}\
    -s ${STATUS_PATH}\
    ${SILENT}";

  ${LAP_CMD}; RC=$?;
  if [[ $RC != 9 ]]; then
      return 3;
  fi
  return 0;
} # END click_accept ()

click_accept $SILENT_MODE; RC=$?;
if [[ $RC == 1 ]]; then
    echo "Could not determine location of LAP tool. ";

    exit $E_FILENOTFOUND;
elif [[ $RC == 2 ]]; then
    echo "Could not identify unique LAP tool location.";

    exit $E_NOTUNIQUE;
elif [[ $RC == 3 ]]; then
    echo "License NOT accepted. Installation will not proceed.";

    exit $E_LAPDECLINE;
fi
